==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiGui/QPaintEvent_shell.cpp <==
#include "QPaintEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QPaintEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPaintEvent")
    QPaintEvent *_ptr = reinterpret_cast<QPaintEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QPaintEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QPaintEvent_shell) ); }

jmethodID QPaintEvent_shell::__shell_javaMethod(int pos) const { return QPaintEvent_shell::__shell()->javaMethod(typeid(QPaintEvent), pos); }

// emitting (writeShellConstructor)
QPaintEvent_shell::QPaintEvent_shell(const QRect& paintRect0)
    : QPaintEvent(paintRect0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QPaintEvent::QPaintEvent_shell(const QRect& paintRect0)", QPaintEvent_shell::__shell())
    QPaintEvent_shell::__shell()->constructed(typeid(QPaintEvent));
}

QPaintEvent_shell::QPaintEvent_shell(const QRegion& paintRegion0)
    : QPaintEvent(paintRegion0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QPaintEvent::QPaintEvent_shell(const QRegion& paintRegion0)", QPaintEvent_shell::__shell())
    QPaintEvent_shell::__shell()->constructed(typeid(QPaintEvent));
}

// emitting (writeShellDestructor)
QPaintEvent_shell::~QPaintEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QPaintEvent::~QPaintEvent()", QPaintEvent_shell::__shell())
    QPaintEvent_shell::__shell()->destructed(typeid(QPaintEvent));
}

void QPaintEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QPaintEvent_shell*>(ptr)->QPaintEvent_shell::__shell()->tryDeleteShell(typeid(QPaintEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QPaintEvent(QRect)
void __qt_construct_QPaintEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPaintEvent(QRect)")
    jobject paintRect0 = __java_arguments[0].l;
    const QRect& __qt_paintRect0 = qtjambi_cast<const QRect& >(__jni_env, paintRect0);
    QPaintEvent *__qt_this = new(__qtjambi_ptr) QPaintEvent_shell(__qt_paintRect0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QPaintEvent(QRegion)
void __qt_construct_QPaintEvent_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPaintEvent(QRegion)")
    jobject paintRegion0 = __java_arguments[0].l;
    const QRegion& __qt_paintRegion0 = qtjambi_cast<const QRegion& >(__jni_env, paintRegion0);
    QPaintEvent *__qt_this = new(__qtjambi_ptr) QPaintEvent_shell(__qt_paintRegion0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QPaintEvent_shell
void __qt_destruct_QPaintEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPaintEvent")
    reinterpret_cast<QPaintEvent_shell*>(ptr)->~QPaintEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QPaintEvent::QPaintEvent(QRect)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPaintEvent_initialize_1native__Lio_qt_gui_QPaintEvent_2Lio_qt_core_QRect_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject paintRect0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPaintEvent::QPaintEvent(QRect)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = paintRect0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPaintEvent_0, sizeof(QPaintEvent_shell), typeid(QPaintEvent), true, &deleter_QPaintEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPaintEvent::QPaintEvent(QRegion)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPaintEvent_initialize_1native__Lio_qt_gui_QPaintEvent_2Lio_qt_gui_QRegion_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject paintRegion0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPaintEvent::QPaintEvent(QRegion)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = paintRegion0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPaintEvent_1, sizeof(QPaintEvent_shell), typeid(QPaintEvent), true, &deleter_QPaintEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPaintEvent::rect()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPaintEvent_rect_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QPaintEvent *__qt_this = QtJambiAPI::objectFromNativeId<QPaintEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPaintEvent::rect()const", __qt_this)
        const QRect& __qt_return_value = __qt_this->rect();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPaintEvent::region()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPaintEvent_region_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QPaintEvent *__qt_this = QtJambiAPI::objectFromNativeId<QPaintEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPaintEvent::region()const", __qt_this)
        const QRegion& __qt_return_value = __qt_this->region();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
void QPaintEvent_access::setErased_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean erased0)
{
    Q_UNUSED(__this_nativeId)
    Q_UNUSED(__jni_env)
    this->QPaintEvent::m_erased = static_cast<bool>(erased0);
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPaintEvent_setErased_1native_1bool__JZ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jboolean erased0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPaintEvent *__qt_this = QtJambiAPI::objectFromNativeId<QPaintEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        static_cast<QPaintEvent_access*>(__qt_this)->setErased_bool(__jni_env, __this_nativeId, erased0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

jboolean QPaintEvent_access::erased(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this_nativeId)
    Q_UNUSED(__jni_env)
    bool  __qt_value = this->QPaintEvent::m_erased;
    return jboolean(__qt_value);
}

extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPaintEvent_erased_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPaintEvent *__qt_this = QtJambiAPI::objectFromNativeId<QPaintEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = static_cast<QPaintEvent_access*>(__qt_this)->erased(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

void QPaintEvent_access::setRect_cref_QRect(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID rect0)
{
    Q_UNUSED(__this_nativeId)
    Q_UNUSED(__jni_env)
    const QRect& __qt_rect0 = QtJambiAPI::valueReferenceFromNativeId<QRect>(rect0);
    this->QPaintEvent::m_rect = __qt_rect0;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPaintEvent_setRect_1native_1cref_1QRect__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rect0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPaintEvent *__qt_this = QtJambiAPI::objectFromNativeId<QPaintEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        static_cast<QPaintEvent_access*>(__qt_this)->setRect_cref_QRect(__jni_env, __this_nativeId, rect0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

void QPaintEvent_access::setRegion_cref_QRegion(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID region0)
{
    Q_UNUSED(__this_nativeId)
    Q_UNUSED(__jni_env)
    const QRegion& __qt_region0 = QtJambiAPI::valueReferenceFromNativeId<QRegion>(region0);
    this->QPaintEvent::m_region = __qt_region0;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPaintEvent_setRegion_1native_1cref_1QRegion__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID region0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPaintEvent *__qt_this = QtJambiAPI::objectFromNativeId<QPaintEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        static_cast<QPaintEvent_access*>(__qt_this)->setRegion_cref_QRegion(__jni_env, __this_nativeId, region0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPaintEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QPaintEvent *__qt_this = QtJambiAPI::objectFromNativeId<QPaintEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QPaintEvent(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QPaintEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QPaintEvent>("QPaintEvent", "io/qt/gui/QPaintEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPaintEvent, {
        ConstructorInfo(&__qt_construct_QPaintEvent_0, "Lio/qt/core/QRect;")
       ,ConstructorInfo(&__qt_construct_QPaintEvent_1, "Lio/qt/gui/QRegion;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPaintEvent);
    registerSizeOfShell(typeId, sizeof(QPaintEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QPaintEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QPaintEvent_shell.cpp <==
#include "QPaintEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QPaintEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPaintEvent")
    QPaintEvent *_ptr = reinterpret_cast<QPaintEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QPaintEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QPaintEvent_shell) ); }

jmethodID QPaintEvent_shell::__shell_javaMethod(int pos) const { return QPaintEvent_shell::__shell()->javaMethod(typeid(QPaintEvent), pos); }

// emitting (writeShellConstructor)
QPaintEvent_shell::QPaintEvent_shell(const QPaintEvent& other0)
    : QPaintEvent(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QPaintEvent::QPaintEvent_shell(const QPaintEvent& other0)", QPaintEvent_shell::__shell())
    QPaintEvent_shell::__shell()->constructed(typeid(QPaintEvent));
}

QPaintEvent_shell::QPaintEvent_shell(const QRect& paintRect0)
    : QPaintEvent(paintRect0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QPaintEvent::QPaintEvent_shell(const QRect& paintRect0)", QPaintEvent_shell::__shell())
    QPaintEvent_shell::__shell()->constructed(typeid(QPaintEvent));
}

QPaintEvent_shell::QPaintEvent_shell(const QRegion& paintRegion0)
    : QPaintEvent(paintRegion0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QPaintEvent::QPaintEvent_shell(const QRegion& paintRegion0)", QPaintEvent_shell::__shell())
    QPaintEvent_shell::__shell()->constructed(typeid(QPaintEvent));
}

// emitting (writeShellDestructor)
QPaintEvent_shell::~QPaintEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QPaintEvent::~QPaintEvent()", QPaintEvent_shell::__shell())
    QPaintEvent_shell::__shell()->destructed(typeid(QPaintEvent));
}

void QPaintEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QPaintEvent_shell*>(ptr)->QPaintEvent_shell::__shell()->tryDeleteShell(typeid(QPaintEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QPaintEvent(QPaintEvent)
void __qt_construct_QPaintEvent_cref_QPaintEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPaintEvent(QPaintEvent)")
    jobject other0 = __java_arguments[0].l;
    const QPaintEvent& __qt_other0 = qtjambi_cast<const QPaintEvent& >(__jni_env, other0);
    QPaintEvent *__qt_this = new(__qtjambi_ptr) QPaintEvent_shell(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QPaintEvent::QPaintEvent(QPaintEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPaintEvent_initialize_1native__Lio_qt_gui_QPaintEvent_2Lio_qt_gui_QPaintEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPaintEvent::QPaintEvent(QPaintEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPaintEvent_cref_QPaintEvent, sizeof(QPaintEvent_shell), typeid(QPaintEvent), true, &deleter_QPaintEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QPaintEvent(QRect)
void __qt_construct_QPaintEvent_cref_QRect(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPaintEvent(QRect)")
    jobject paintRect0 = __java_arguments[0].l;
    const QRect& __qt_paintRect0 = qtjambi_cast<const QRect& >(__jni_env, paintRect0);
    QPaintEvent *__qt_this = new(__qtjambi_ptr) QPaintEvent_shell(__qt_paintRect0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QPaintEvent::QPaintEvent(QRect)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPaintEvent_initialize_1native__Lio_qt_gui_QPaintEvent_2Lio_qt_core_QRect_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject paintRect0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPaintEvent::QPaintEvent(QRect)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = paintRect0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPaintEvent_cref_QRect, sizeof(QPaintEvent_shell), typeid(QPaintEvent), true, &deleter_QPaintEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QPaintEvent(QRegion)
void __qt_construct_QPaintEvent_cref_QRegion(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPaintEvent(QRegion)")
    jobject paintRegion0 = __java_arguments[0].l;
    const QRegion& __qt_paintRegion0 = qtjambi_cast<const QRegion& >(__jni_env, paintRegion0);
    QPaintEvent *__qt_this = new(__qtjambi_ptr) QPaintEvent_shell(__qt_paintRegion0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QPaintEvent::QPaintEvent(QRegion)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPaintEvent_initialize_1native__Lio_qt_gui_QPaintEvent_2Lio_qt_gui_QRegion_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject paintRegion0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPaintEvent::QPaintEvent(QRegion)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = paintRegion0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPaintEvent_cref_QRegion, sizeof(QPaintEvent_shell), typeid(QPaintEvent), true, &deleter_QPaintEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QPaintEvent_shell
void __qt_destruct_QPaintEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPaintEvent")
    reinterpret_cast<QPaintEvent_shell*>(ptr)->~QPaintEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QPaintEvent::rect()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPaintEvent_rect_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QPaintEvent *__qt_this = QtJambiAPI::objectFromNativeId<QPaintEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPaintEvent::rect()const", __qt_this)
        const QRect& __qt_return_value = __qt_this->rect();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPaintEvent::region()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPaintEvent_region_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QPaintEvent *__qt_this = QtJambiAPI::objectFromNativeId<QPaintEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPaintEvent::region()const", __qt_this)
        const QRegion& __qt_return_value = __qt_this->region();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
void QPaintEvent_access::setErased_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean erased0)
{
    Q_UNUSED(__this_nativeId)
    Q_UNUSED(__jni_env)
    this->QPaintEvent::m_erased = static_cast<bool>(erased0);
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPaintEvent_setErased_1native_1bool__JZ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jboolean erased0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPaintEvent *__qt_this = QtJambiAPI::objectFromNativeId<QPaintEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        static_cast<QPaintEvent_access*>(__qt_this)->setErased_bool(__jni_env, __this_nativeId, erased0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

jboolean QPaintEvent_access::erased(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this_nativeId)
    Q_UNUSED(__jni_env)
    bool  __qt_value = this->QPaintEvent::m_erased;
    return jboolean(__qt_value);
}

extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPaintEvent_erased_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPaintEvent *__qt_this = QtJambiAPI::objectFromNativeId<QPaintEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = static_cast<QPaintEvent_access*>(__qt_this)->erased(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

void QPaintEvent_access::setRect_cref_QRect(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID rect0)
{
    Q_UNUSED(__this_nativeId)
    Q_UNUSED(__jni_env)
    const QRect& __qt_rect0 = QtJambiAPI::valueReferenceFromNativeId<QRect>(rect0);
    this->QPaintEvent::m_rect = __qt_rect0;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPaintEvent_setRect_1native_1cref_1QRect__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rect0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPaintEvent *__qt_this = QtJambiAPI::objectFromNativeId<QPaintEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        static_cast<QPaintEvent_access*>(__qt_this)->setRect_cref_QRect(__jni_env, __this_nativeId, rect0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

void QPaintEvent_access::setRegion_cref_QRegion(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID region0)
{
    Q_UNUSED(__this_nativeId)
    Q_UNUSED(__jni_env)
    const QRegion& __qt_region0 = QtJambiAPI::valueReferenceFromNativeId<QRegion>(region0);
    this->QPaintEvent::m_region = __qt_region0;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPaintEvent_setRegion_1native_1cref_1QRegion__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID region0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPaintEvent *__qt_this = QtJambiAPI::objectFromNativeId<QPaintEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        static_cast<QPaintEvent_access*>(__qt_this)->setRegion_cref_QRegion(__jni_env, __this_nativeId, region0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPaintEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QPaintEvent *__qt_this = QtJambiAPI::objectFromNativeId<QPaintEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QPaintEvent(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QPaintEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QPaintEvent>("QPaintEvent", "io/qt/gui/QPaintEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPaintEvent, {
        ConstructorInfo(&__qt_construct_QPaintEvent_cref_QPaintEvent, "Lio/qt/gui/QPaintEvent;")
       ,ConstructorInfo(&__qt_construct_QPaintEvent_cref_QRect, "Lio/qt/core/QRect;")
       ,ConstructorInfo(&__qt_construct_QPaintEvent_cref_QRegion, "Lio/qt/gui/QRegion;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPaintEvent);
    registerSizeOfShell(typeId, sizeof(QPaintEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QPaintEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
